@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -39,28 +39,21 @@
 
 /* Convince macros for calling precision-specific math functions */
 #if defined(SUNDIALS_DOUBLE_PRECISION)
-#define EXP(x)  (exp((x)))
-#define SQRT(x) (sqrt((x)))
-#define LOG(x)  (log((x)))
+#define EXP(x) (exp((x)))
+#define LOG(x) (log((x)))
 #elif defined(SUNDIALS_SINGLE_PRECISION)
-#define EXP(x)  (expf((x)))
-#define SQRT(x) (sqrtf((x)))
-#define LOG(x)  (logf((x)))
+#define EXP(x) (expf((x)))
+#define LOG(x) (logf((x)))
 #elif defined(SUNDIALS_EXTENDED_PRECISION)
-#define EXP(x)  (expl((x)))
-#define SQRT(x) (sqrtl((x)))
-#define LOG(x)  (logl((x)))
+#define EXP(x) (expl((x)))
+#define LOG(x) (logl((x)))
 #endif
 
 /* Convince macros for using precision-specific format specifiers */
 #if defined(SUNDIALS_EXTENDED_PRECISION)
-#define GSYM "Lg"
 #define ESYM "Le"
-#define FSYM "Lf"
 #else
-#define GSYM "g"
 #define ESYM "e"
-#define FSYM "f"
 #endif
 
 /* ----------------------- *
@@ -174,14 +167,13 @@ int main(int argc, char* argv[])
   if (check_flag(flag, "SUNContext_Create")) { return 1; }
 
   /* Create serial vector and set the initial condition values */
-  y = N_VNew_Serial(2, ctx);
+  y = N_VNew_Serial(1, ctx);
   if (check_ptr(y, "N_VNew_Serial")) { return 1; }
 
   ydata = N_VGetArrayPointer(y);
   if (check_ptr(ydata, "N_VGetArrayPointer")) { return 1; }
 
-  ydata[0] = SUN_RCONST(1.0);
-  ydata[1] = SUN_RCONST(0.5);
+  ydata[0] = SUN_RCONST(0.5);
 
   ytrue = N_VClone(y);
   if (check_ptr(ytrue, "N_VClone")) { return 1; }
@@ -194,6 +186,10 @@ int main(int argc, char* argv[])
   else { arkode_mem = ARKStepCreate(f, NULL, t0, y, ctx); }
   if (check_ptr(arkode_mem, "ARKStepCreate")) { return 1; }
 
+  /* Set order */
+  flag = ARKodeSetOrder(arkode_mem, 2);
+  if (check_flag(flag, "ARKodeSetOrder")) { return 1; }
+
   /* Specify tolerances */
   flag = ARKodeSStolerances(arkode_mem, reltol, abstol);
   if (check_flag(flag, "ARKodeSStolerances")) { return 1; }
@@ -208,7 +204,7 @@ int main(int argc, char* argv[])
   if (implicit)
   {
     /* Create dense matrix and linear solver */
-    A = SUNDenseMatrix(2, 2, ctx);
+    A = SUNDenseMatrix(1, 1, ctx);
     if (check_ptr(A, "SUNDenseMatrix")) { return 1; }
 
     LS = SUNLinSol_Dense(y, A, ctx);
@@ -222,11 +218,6 @@ int main(int argc, char* argv[])
     flag = ARKodeSetJacFn(arkode_mem, Jac);
     if (check_flag(flag, "ARKodeSetJacFn")) { return 1; }
 
-    /* Select a Butcher table with non-negative b values */
-    flag = ARKStepSetTableName(arkode_mem, "ARKODE_ARK2_DIRK_3_1_2",
-                               "ARKODE_ERK_NONE");
-    if (check_flag(flag, "ARKStepSetTableName")) { return 1; }
-
     /* Tighten nonlinear solver tolerance */
     flag = ARKodeSetNonlinConvCoef(arkode_mem, SUN_RCONST(0.01));
     if (check_flag(flag, "ARKodeSetNonlinConvCoef")) { return 1; }
@@ -318,8 +309,11 @@ int main(int argc, char* argv[])
   flag = ARKodeGetNumErrTestFails(arkode_mem, &netf);
   check_flag(flag, "ARKodeGetNumErrTestFails");
 
-  flag = ARKStepGetNumRhsEvals(arkode_mem, &nfe, &nfi);
-  check_flag(flag, "ARKStepGetNumRhsEvals");
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 0, &nfe);
+  check_flag(flag, "ARKodeGetNumRhsEvals");
+
+  flag = ARKodeGetNumRhsEvals(arkode_mem, 1, &nfi);
+  check_flag(flag, "ARKodeGetNumRhsEvals");
 
   printf("\nFinal Solver Statistics:\n");
   printf("   Internal solver steps = %li (attempted = %li)\n", nst, nst_a);
@@ -442,7 +436,7 @@ int JacEnt(N_Vector y, N_Vector J, void* user_data)
 int ans(sunrealtype t, N_Vector y)
 {
   sunrealtype* ydata = N_VGetArrayPointer(y);
-  ydata[0]           = LOG(EXP(SUN_RCONST(-0.5)) + t);
+  ydata[0]           = -LOG(EXP(SUN_RCONST(-0.5)) + t);
   return 0;
 }
 
