@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -18,9 +18,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "sundials/priv/sundials_errors_impl.h"
-#include "sundials/sundials_errors.h"
-#include "sundials/sundials_types.h"
+#include <sundials/priv/sundials_errors_impl.h>
+#include <sundials/sundials_errors.h>
+#include <sundials/sundials_types.h>
 #ifdef MANYVECTOR_BUILD_WITH_MPI
 #include <nvector/nvector_mpimanyvector.h>
 #include <sundials/priv/sundials_mpi_errors_impl.h>
@@ -31,6 +31,8 @@
 #include <sundials/priv/sundials_errors_impl.h>
 #include <sundials/sundials_core.h>
 
+#include "sundials_macros.h"
+
 /* Macro to handle separate MPI-aware/unaware installations */
 #ifdef MANYVECTOR_BUILD_WITH_MPI
 #define MVAPPEND(fun) fun##_MPIManyVector
@@ -39,7 +41,9 @@
 #endif
 
 #define ZERO SUN_RCONST(0.0)
-#define ONE  SUN_RCONST(1.0)
+#ifdef MANYVECTOR_BUILD_WITH_MPI
+#define ONE SUN_RCONST(1.0)
+#endif
 
 /* -----------------------------------------------------------------
    ManyVector content accessor macros
@@ -472,7 +476,7 @@ sunindextype MVAPPEND(N_VGetNumSubvectors)(N_Vector v)
 
 /* Returns vector type ID. Used to identify vector implementation
    from abstract N_Vector interface. */
-N_Vector_ID MVAPPEND(N_VGetVectorID)(N_Vector v)
+N_Vector_ID MVAPPEND(N_VGetVectorID)(SUNDIALS_MAYBE_UNUSED N_Vector v)
 {
 #ifdef MANYVECTOR_BUILD_WITH_MPI
   return (SUNDIALS_NVEC_MPIMANYVECTOR);
@@ -595,9 +599,6 @@ MPI_Comm N_VGetCommunicator_MPIManyVector(N_Vector v)
 {
   return (MANYVECTOR_COMM(v));
 }
-#else
-/* This function retrieves the MPI Communicator from a ManyVector object. */
-SUNComm N_VGetCommunicator_ManyVector(N_Vector v) { return SUN_COMM_NULL; }
 #endif
 
 /* This function retrieves the global length of a ManyVector object. */
