@@ -3,7 +3,7 @@
  * Based on sundials_sptfqmr.c code, written by Aaron Collier @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -18,11 +18,13 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+
 #include <sundials/priv/sundials_errors_impl.h>
 #include <sundials/sundials_math.h>
 #include <sunlinsol/sunlinsol_sptfqmr.h>
 
 #include "sundials_logger_impl.h"
+#include "sundials_macros.h"
 
 #define ZERO SUN_RCONST(0.0)
 #define ONE  SUN_RCONST(1.0)
@@ -184,12 +186,12 @@ SUNErrCode SUNLinSol_SPTFQMRSetMaxl(SUNLinearSolver S, int maxl)
  * -----------------------------------------------------------------
  */
 
-SUNLinearSolver_Type SUNLinSolGetType_SPTFQMR(SUNLinearSolver S)
+SUNLinearSolver_Type SUNLinSolGetType_SPTFQMR(SUNDIALS_MAYBE_UNUSED SUNLinearSolver S)
 {
   return (SUNLINEARSOLVER_ITERATIVE);
 }
 
-SUNLinearSolver_ID SUNLinSolGetID_SPTFQMR(SUNLinearSolver S)
+SUNLinearSolver_ID SUNLinSolGetID_SPTFQMR(SUNDIALS_MAYBE_UNUSED SUNLinearSolver S)
 {
   return (SUNLINEARSOLVER_SPTFQMR);
 }
@@ -260,7 +262,7 @@ SUNErrCode SUNLinSolSetZeroGuess_SPTFQMR(SUNLinearSolver S, sunbooleantype onoff
   return SUN_SUCCESS;
 }
 
-int SUNLinSolSetup_SPTFQMR(SUNLinearSolver S, SUNMatrix A)
+int SUNLinSolSetup_SPTFQMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A)
 {
   SUNFunctionBegin(S->sunctx);
 
@@ -289,8 +291,8 @@ int SUNLinSolSetup_SPTFQMR(SUNLinearSolver S, SUNMatrix A)
   return SUN_SUCCESS;
 }
 
-int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
-                           N_Vector b, sunrealtype delta)
+int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
+                           N_Vector x, N_Vector b, sunrealtype delta)
 {
   SUNFunctionBegin(S->sunctx);
 
@@ -312,7 +314,7 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
   N_Vector Xv[3];
   int status = SUN_SUCCESS;
 
-  /* Make local shorcuts to solver variables. */
+  /* Make local shortcuts to solver variables. */
   l_max     = SPTFQMR_CONTENT(S)->maxl;
   r_star    = SPTFQMR_CONTENT(S)->r_star;
   q         = SPTFQMR_CONTENT(S)->q;
@@ -348,11 +350,19 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
   scale_x    = (sx != NULL);
   scale_b    = (sb != NULL);
 
+  SUNLogInfo(S->sunctx->logger, "linear-solver", "solver = sptfqmr");
+
+  SUNLogInfo(S->sunctx->logger, "begin-linear-iterate", "");
+
   /* Check for unsupported use case */
   if (preOnRight && !(*zeroguess))
   {
     *zeroguess  = SUNFALSE;
     LASTFLAG(S) = SUN_ERR_ARG_INCOMPATIBLE;
+
+    SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+               "status = failed unsupported configuration");
+
     return SUN_ERR_ARG_INCOMPATIBLE;
   }
 
@@ -377,6 +387,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
       *zeroguess  = SUNFALSE;
       LASTFLAG(S) = (status < 0) ? SUNLS_ATIMES_FAIL_UNREC
                                  : SUNLS_ATIMES_FAIL_REC;
+
+      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                 "status = failed matvec, retval = %d", status);
+
       return (LASTFLAG(S));
     }
     N_VLinearSum(ONE, b, -ONE, r_star, r_star);
@@ -392,6 +406,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
       *zeroguess  = SUNFALSE;
       LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                  : SUNLS_PSOLVE_FAIL_REC;
+
+      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                 "status = failed preconditioner solve, retval = %d", status);
+
       return (LASTFLAG(S));
     }
   }
@@ -423,19 +441,20 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
      to do anything */
   *res_norm = r_init_norm = SUNRsqrt(rho[0]);
 
-#if SUNDIALS_LOGGING_LEVEL >= SUNDIALS_LOGGING_INFO
-  SUNLogger_QueueMsg(S->sunctx->logger, SUN_LOGLEVEL_INFO,
-                     "SUNLinSolSolve_SPFTQMR", "initial-residual",
-                     "nli = %li, resnorm = %.16g", (long int)0, *res_norm);
-#endif
-
   if (r_init_norm <= delta)
   {
     *zeroguess  = SUNFALSE;
     LASTFLAG(S) = SUN_SUCCESS;
+
+    SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+               "cur-iter = 0, res-norm = %.16g, status = success", *res_norm);
+
     return (LASTFLAG(S));
   }
 
+  SUNLogInfo(S->sunctx->logger, "linear-iterate",
+             "cur-iter = 0, res-norm = %.16g", *res_norm);
+
   /* Set v = A*r_0 (preconditioned and scaled) */
   if (scale_x)
   {
@@ -458,6 +477,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
       *zeroguess  = SUNFALSE;
       LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                  : SUNLS_PSOLVE_FAIL_REC;
+
+      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                 "status = failed preconditioner solve, retval = %d", status);
+
       return (LASTFLAG(S));
     }
   }
@@ -467,6 +490,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
   {
     *zeroguess = SUNFALSE;
     LASTFLAG(S) = (status < 0) ? SUNLS_ATIMES_FAIL_UNREC : SUNLS_ATIMES_FAIL_REC;
+
+    SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+               "status = failed matvec, retval = %d", status);
+
     return (LASTFLAG(S));
   }
 
@@ -478,6 +505,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
       *zeroguess  = SUNFALSE;
       LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                  : SUNLS_PSOLVE_FAIL_REC;
+
+      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                 "status = failed preconditioner solve, retval = %d", status);
+
       return (LASTFLAG(S));
     }
   }
@@ -518,9 +549,13 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
   tau   = r_init_norm;
   v_bar = eta = ZERO;
 
+  SUNLogInfo(S->sunctx->logger, "end-linear-iterate", "status = continue");
+
   /* START outer loop */
   for (n = 0; n < l_max; ++n)
   {
+    SUNLogInfo(S->sunctx->logger, "begin-linear-iterate", "");
+
     /* Increment linear iteration counter */
     (*nli)++;
 
@@ -554,6 +589,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
         *zeroguess  = SUNFALSE;
         LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                    : SUNLS_PSOLVE_FAIL_REC;
+
+        SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                   "status = failed preconditioner solve, retval = %d", status);
+
         return (LASTFLAG(S));
       }
     }
@@ -564,6 +603,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
       *zeroguess  = SUNFALSE;
       LASTFLAG(S) = (status < 0) ? SUNLS_ATIMES_FAIL_UNREC
                                  : SUNLS_ATIMES_FAIL_REC;
+
+      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                 "status = failed matvec, retval = %d", status);
+
       return (LASTFLAG(S));
     }
 
@@ -575,6 +618,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
         *zeroguess  = SUNFALSE;
         LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                    : SUNLS_PSOLVE_FAIL_REC;
+
+        SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                   "status = failed preconditioner solve, retval = %d", status);
+
         return (LASTFLAG(S));
       }
     }
@@ -652,16 +699,13 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
       /* NOTE: just use approximation to norm of residual, if possible */
       *res_norm = r_curr_norm = tau * SUNRsqrt(m + 1);
 
-#if SUNDIALS_LOGGING_LEVEL >= SUNDIALS_LOGGING_INFOs
-      SUNLogger_QueueMsg(S->sunctx->logger, SUN_LOGLEVEL_INFO,
-                         "SUNLinSolSolve_SPTFQMR", "iterate-residual",
-                         "nli = %li, resnorm = %.16g", (long int)0, *res_norm);
-#endif
-
       /* Exit inner loop if iteration has converged based upon approximation
          to norm of current residual */
       if (r_curr_norm <= delta)
       {
+        SUNLogInfo(S->sunctx->logger, "linear-iterate",
+                   "cur-iter = %i, res-norm = %.16g", n + 1, *nli, *res_norm);
+
         converged = SUNTRUE;
         break;
       }
@@ -700,7 +744,12 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
           {
             *zeroguess  = SUNFALSE;
             LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
-                                       : SUNLS_PSOLVE_FAIL_UNREC;
+                                       : SUNLS_PSOLVE_FAIL_REC;
+
+            SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                       "status = failed preconditioner solve, retval = %d",
+                       status);
+
             return (LASTFLAG(S));
           }
           N_VScale(ONE, vtemp2, vtemp1);
@@ -713,6 +762,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
           *zeroguess  = SUNFALSE;
           LASTFLAG(S) = (status < 0) ? SUNLS_ATIMES_FAIL_UNREC
                                      : SUNLS_ATIMES_FAIL_REC;
+
+          SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                     "status = failed matvec, retval = %d", status);
+
           return (LASTFLAG(S));
         }
 
@@ -724,6 +777,11 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
             *zeroguess  = SUNFALSE;
             LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                        : SUNLS_PSOLVE_FAIL_REC;
+
+            SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                       "status = failed preconditioner solve, retval = %d",
+                       status);
+
             return (LASTFLAG(S));
           }
         }
@@ -756,6 +814,11 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
               *zeroguess  = SUNFALSE;
               LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                          : SUNLS_PSOLVE_FAIL_REC;
+
+              SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                         "status = failed preconditioner solve, retval = %d",
+                         status);
+
               return (LASTFLAG(S));
             }
           }
@@ -781,11 +844,17 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
            (meaning exit if we have converged) */
         if (r_curr_norm <= delta)
         {
+          SUNLogInfo(S->sunctx->logger, "linear-iterate",
+                     "cur-iter = %i, res-norm = %.16g", n + 1, *nli, *res_norm);
+
           converged = SUNTRUE;
           break;
         }
       }
 
+      SUNLogInfo(S->sunctx->logger, "linear-iterate",
+                 "cur-iter = %i, res-norm = %.16g", n + 1, *nli, *res_norm);
+
     } /* END inner loop */
 
     /* If converged, then exit outer loop as well */
@@ -836,6 +905,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
         *zeroguess  = SUNFALSE;
         LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                    : SUNLS_PSOLVE_FAIL_REC;
+
+        SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                   "status = failed preconditioner solve, retval = %d", status);
+
         return (LASTFLAG(S));
       }
     }
@@ -846,6 +919,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
       *zeroguess  = SUNFALSE;
       LASTFLAG(S) = (status < 0) ? SUNLS_ATIMES_FAIL_UNREC
                                  : SUNLS_ATIMES_FAIL_REC;
+
+      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                 "status = failed matvec, retval = %d", status);
+
       return (LASTFLAG(S));
     }
 
@@ -857,6 +934,10 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
         *zeroguess  = SUNFALSE;
         LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                    : SUNLS_PSOLVE_FAIL_REC;
+
+        SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                   "status = failed preconditioner solve, retval = %d", status);
+
         return (LASTFLAG(S));
       }
     }
@@ -883,6 +964,9 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
     SUNCheckLastErr();
     rho[0] = rho[1];
 
+    SUNLogInfoIf(n < l_max - 1, S->sunctx->logger, "end-linear-iterate",
+                 "status = continue");
+
   } /* END outer loop */
 
   /* Determine return value */
@@ -903,7 +987,11 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
       {
         *zeroguess  = SUNFALSE;
         LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
-                                   : SUNLS_PSOLVE_FAIL_UNREC;
+                                   : SUNLS_PSOLVE_FAIL_REC;
+
+        SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                   "status = failed preconditioner solve, retval = %d", status);
+
         return (LASTFLAG(S));
       }
       N_VScale(ONE, vtemp1, x);
@@ -911,14 +999,29 @@ int SUNLinSolSolve_SPTFQMR(SUNLinearSolver S, SUNMatrix A, N_Vector x,
     }
 
     *zeroguess = SUNFALSE;
-    if (converged == SUNTRUE) { LASTFLAG(S) = SUN_SUCCESS; }
-    else { LASTFLAG(S) = SUNLS_RES_REDUCED; }
+    if (converged == SUNTRUE)
+    {
+      SUNLogInfo(S->sunctx->logger, "end-linear-iterate", "status = success");
+
+      LASTFLAG(S) = SUN_SUCCESS;
+    }
+    else
+    {
+      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+                 "status = failed residual reduced");
+
+      LASTFLAG(S) = SUNLS_RES_REDUCED;
+    }
     return (LASTFLAG(S));
   }
   else
   {
     *zeroguess  = SUNFALSE;
     LASTFLAG(S) = SUNLS_CONV_FAIL;
+
+    SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+               "status = failed max iterations");
+
     return (LASTFLAG(S));
   }
 }
